#[non_exhaustive]pub struct CreateCollectionGroupInput {
pub name: Option<String>,
pub standby_replicas: Option<StandbyReplicas>,
pub description: Option<String>,
pub tags: Option<Vec<Tag>>,
pub capacity_limits: Option<CollectionGroupCapacityLimits>,
pub generation: Option<ServerlessGeneration>,
pub client_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>The name of the collection group.
standby_replicas: Option<StandbyReplicas>Indicates whether standby replicas should be used for a collection group.
description: Option<String>A description of the collection group.
An arbitrary set of tags (key–value pairs) to associate with the OpenSearch Serverless collection group.
capacity_limits: Option<CollectionGroupCapacityLimits>The capacity limits for the collection group, in OpenSearch Compute Units (OCUs). These limits control the maximum and minimum capacity for collections within the group.
generation: Option<ServerlessGeneration>The generation of Amazon OpenSearch Serverless for the collection group. Valid values are CLASSIC and NEXTGEN.
client_token: Option<String>Unique, case-sensitive identifier to ensure idempotency of the request.
Implementations
Sourceimpl CreateCollectionGroupInput
impl CreateCollectionGroupInput
Sourcepub fn standby_replicas(&self) -> Option<&StandbyReplicas>
pub fn standby_replicas(&self) -> Option<&StandbyReplicas>
Indicates whether standby replicas should be used for a collection group.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description of the collection group.
An arbitrary set of tags (key–value pairs) to associate with the OpenSearch Serverless collection group.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .tags.is_none().
Sourcepub fn capacity_limits(&self) -> Option<&CollectionGroupCapacityLimits>
pub fn capacity_limits(&self) -> Option<&CollectionGroupCapacityLimits>
The capacity limits for the collection group, in OpenSearch Compute Units (OCUs). These limits control the maximum and minimum capacity for collections within the group.
Sourcepub fn generation(&self) -> Option<&ServerlessGeneration>
pub fn generation(&self) -> Option<&ServerlessGeneration>
The generation of Amazon OpenSearch Serverless for the collection group. Valid values are CLASSIC and NEXTGEN.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
Unique, case-sensitive identifier to ensure idempotency of the request.
Sourceimpl CreateCollectionGroupInput
impl CreateCollectionGroupInput
Sourcepub fn builder() -> CreateCollectionGroupInputBuilder
pub fn builder() -> CreateCollectionGroupInputBuilder
Creates a new builder-style object to manufacture CreateCollectionGroupInput.