#[non_exhaustive]pub struct UpdateCollectionGroupInput {
pub id: Option<String>,
pub description: Option<String>,
pub capacity_limits: Option<CollectionGroupCapacityLimits>,
pub client_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>The unique identifier of the collection group to update.
description: Option<String>A new description for the collection group.
capacity_limits: Option<CollectionGroupCapacityLimits>Updated capacity limits for the collection group, in OpenSearch Compute Units (OCUs).
client_token: Option<String>Unique, case-sensitive identifier to ensure idempotency of the request.
Implementations
Sourceimpl UpdateCollectionGroupInput
impl UpdateCollectionGroupInput
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A new description for the collection group.
Sourcepub fn capacity_limits(&self) -> Option<&CollectionGroupCapacityLimits>
pub fn capacity_limits(&self) -> Option<&CollectionGroupCapacityLimits>
Updated capacity limits for the collection group, in OpenSearch Compute Units (OCUs).
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
Unique, case-sensitive identifier to ensure idempotency of the request.
Sourceimpl UpdateCollectionGroupInput
impl UpdateCollectionGroupInput
Sourcepub fn builder() -> UpdateCollectionGroupInputBuilder
pub fn builder() -> UpdateCollectionGroupInputBuilder
Creates a new builder-style object to manufacture UpdateCollectionGroupInput.