#[non_exhaustive]pub struct CreateCollectionGroupDetailBuilder { /* private fields */ }Expand description
A builder for CreateCollectionGroupDetail.
Implementations
Sourceimpl CreateCollectionGroupDetailBuilder
impl CreateCollectionGroupDetailBuilder
Sourcepub fn id(self, input: impl Into<String>) -> Self
pub fn id(self, input: impl Into<String>) -> Self
The unique identifier of the collection group.
Sourcepub fn set_id(self, input: Option<String>) -> Self
pub fn set_id(self, input: Option<String>) -> Self
The unique identifier of the collection group.
Sourcepub fn arn(self, input: impl Into<String>) -> Self
pub fn arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the collection group.
Sourcepub fn set_arn(self, input: Option<String>) -> Self
pub fn set_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the collection group.
Sourcepub fn get_arn(&self) -> &Option<String>
pub fn get_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the collection group.
Sourcepub fn standby_replicas(self, input: StandbyReplicas) -> Self
pub fn standby_replicas(self, input: StandbyReplicas) -> Self
Indicates whether standby replicas are used for the collection group.
Sourcepub fn set_standby_replicas(self, input: Option<StandbyReplicas>) -> Self
pub fn set_standby_replicas(self, input: Option<StandbyReplicas>) -> Self
Indicates whether standby replicas are used for the collection group.
Sourcepub fn get_standby_replicas(&self) -> &Option<StandbyReplicas>
pub fn get_standby_replicas(&self) -> &Option<StandbyReplicas>
Indicates whether standby replicas are used for the collection group.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The description of the collection group.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The description of the collection group.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The description of the collection group.
Appends an item to tags.
To override the contents of this collection use set_tags.
A map of key-value pairs associated with the collection group.
A map of key-value pairs associated with the collection group.
A map of key-value pairs associated with the collection group.
Sourcepub fn created_date(self, input: i64) -> Self
pub fn created_date(self, input: i64) -> Self
The Epoch time when the collection group was created.
Sourcepub fn set_created_date(self, input: Option<i64>) -> Self
pub fn set_created_date(self, input: Option<i64>) -> Self
The Epoch time when the collection group was created.
Sourcepub fn get_created_date(&self) -> &Option<i64>
pub fn get_created_date(&self) -> &Option<i64>
The Epoch time when the collection group was created.
Sourcepub fn capacity_limits(self, input: CollectionGroupCapacityLimits) -> Self
pub fn capacity_limits(self, input: CollectionGroupCapacityLimits) -> Self
The capacity limits for the collection group, in OpenSearch Compute Units (OCUs).
Sourcepub fn set_capacity_limits(
self,
input: Option<CollectionGroupCapacityLimits>,
) -> Self
pub fn set_capacity_limits( self, input: Option<CollectionGroupCapacityLimits>, ) -> Self
The capacity limits for the collection group, in OpenSearch Compute Units (OCUs).
Sourcepub fn get_capacity_limits(&self) -> &Option<CollectionGroupCapacityLimits>
pub fn get_capacity_limits(&self) -> &Option<CollectionGroupCapacityLimits>
The capacity limits for the collection group, in OpenSearch Compute Units (OCUs).
Sourcepub fn generation(self, input: ServerlessGeneration) -> Self
pub fn generation(self, input: ServerlessGeneration) -> Self
The generation of Amazon OpenSearch Serverless for the collection group.
Sourcepub fn set_generation(self, input: Option<ServerlessGeneration>) -> Self
pub fn set_generation(self, input: Option<ServerlessGeneration>) -> Self
The generation of Amazon OpenSearch Serverless for the collection group.
Sourcepub fn get_generation(&self) -> &Option<ServerlessGeneration>
pub fn get_generation(&self) -> &Option<ServerlessGeneration>
The generation of Amazon OpenSearch Serverless for the collection group.
Sourcepub fn build(self) -> CreateCollectionGroupDetail
pub fn build(self) -> CreateCollectionGroupDetail
Consumes the builder and constructs a CreateCollectionGroupDetail.