#[non_exhaustive]pub struct CollectionGroupDetail {
pub id: Option<String>,
pub arn: Option<String>,
pub name: Option<String>,
pub standby_replicas: Option<StandbyReplicas>,
pub description: Option<String>,
pub tags: Option<Vec<Tag>>,
pub created_date: Option<i64>,
pub capacity_limits: Option<CollectionGroupCapacityLimits>,
pub current_capacity: Option<CurrentCapacity>,
pub number_of_collections: Option<i32>,
pub generation: Option<ServerlessGeneration>,
}Expand description
Details about a collection group.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>The unique identifier of the collection group.
arn: Option<String>The Amazon Resource Name (ARN) of the collection group.
name: Option<String>The name of the collection group.
standby_replicas: Option<StandbyReplicas>Indicates whether standby replicas are used for the collection group.
description: Option<String>The description of the collection group.
A map of key-value pairs associated with the collection group.
created_date: Option<i64>The Epoch time when the collection group was created.
capacity_limits: Option<CollectionGroupCapacityLimits>The capacity limits for the collection group, in OpenSearch Compute Units (OCUs).
current_capacity: Option<CurrentCapacity>Current search and indexing capacity for the collection group.
number_of_collections: Option<i32>The number of collections associated with the collection group.
generation: Option<ServerlessGeneration>The generation of Amazon OpenSearch Serverless for the collection group.
Implementations
Sourceimpl CollectionGroupDetail
impl CollectionGroupDetail
Sourcepub fn standby_replicas(&self) -> Option<&StandbyReplicas>
pub fn standby_replicas(&self) -> Option<&StandbyReplicas>
Indicates whether standby replicas are used for the collection group.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The description of the collection group.
A map of key-value pairs associated with the collection group.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .tags.is_none().
Sourcepub fn created_date(&self) -> Option<i64>
pub fn created_date(&self) -> Option<i64>
The Epoch time when the collection group was created.
Sourcepub fn capacity_limits(&self) -> Option<&CollectionGroupCapacityLimits>
pub fn capacity_limits(&self) -> Option<&CollectionGroupCapacityLimits>
The capacity limits for the collection group, in OpenSearch Compute Units (OCUs).
Sourcepub fn current_capacity(&self) -> Option<&CurrentCapacity>
pub fn current_capacity(&self) -> Option<&CurrentCapacity>
Current search and indexing capacity for the collection group.
Sourcepub fn number_of_collections(&self) -> Option<i32>
pub fn number_of_collections(&self) -> Option<i32>
The number of collections associated with the collection group.
Sourcepub fn generation(&self) -> Option<&ServerlessGeneration>
pub fn generation(&self) -> Option<&ServerlessGeneration>
The generation of Amazon OpenSearch Serverless for the collection group.
Sourceimpl CollectionGroupDetail
impl CollectionGroupDetail
Sourcepub fn builder() -> CollectionGroupDetailBuilder
pub fn builder() -> CollectionGroupDetailBuilder
Creates a new builder-style object to manufacture CollectionGroupDetail.