#[non_exhaustive]pub struct CollectionGroupErrorDetail {
pub id: Option<String>,
pub name: Option<String>,
pub error_message: Option<String>,
pub error_code: Option<String>,
}Expand description
Error details for a collection group operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>If the request contains collection group IDs, the response includes the IDs provided in the request.
name: Option<String>If the request contains collection group names, the response includes the names provided in the request.
error_message: Option<String>A description of the error. For example, The specified Collection Group is not found.
error_code: Option<String>The error code for the request. For example, NOT_FOUND.
Implementations
Sourceimpl CollectionGroupErrorDetail
impl CollectionGroupErrorDetail
Sourcepub fn id(&self) -> Option<&str>
pub fn id(&self) -> Option<&str>
If the request contains collection group IDs, the response includes the IDs provided in the request.
Sourcepub fn name(&self) -> Option<&str>
pub fn name(&self) -> Option<&str>
If the request contains collection group names, the response includes the names provided in the request.
Sourcepub fn error_message(&self) -> Option<&str>
pub fn error_message(&self) -> Option<&str>
A description of the error. For example, The specified Collection Group is not found.
Sourcepub fn error_code(&self) -> Option<&str>
pub fn error_code(&self) -> Option<&str>
The error code for the request. For example, NOT_FOUND.
Sourceimpl CollectionGroupErrorDetail
impl CollectionGroupErrorDetail
Sourcepub fn builder() -> CollectionGroupErrorDetailBuilder
pub fn builder() -> CollectionGroupErrorDetailBuilder
Creates a new builder-style object to manufacture CollectionGroupErrorDetail.