#[non_exhaustive]pub struct CollectionGroupSummary {
pub id: Option<String>,
pub arn: Option<String>,
pub name: Option<String>,
pub number_of_collections: Option<i32>,
pub created_date: Option<i64>,
pub capacity_limits: Option<CollectionGroupCapacityLimits>,
pub generation: Option<ServerlessGeneration>,
}Expand description
Summary information about a collection group.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>The unique identifier of the collection group.
arn: Option<String>The Amazon Resource Name (ARN) of the collection group.
name: Option<String>The name of the collection group.
number_of_collections: Option<i32>The number of collections within the collection group.
created_date: Option<i64>The Epoch time when the collection group was created.
capacity_limits: Option<CollectionGroupCapacityLimits>Capacity limits for a collection group. These limits define the minimum and maximum OpenSearch Compute Units (OCUs) for indexing and search operations that can be used by collections in the group.
generation: Option<ServerlessGeneration>The generation of Amazon OpenSearch Serverless for the collection group.
Implementations
Sourceimpl CollectionGroupSummary
impl CollectionGroupSummary
Sourcepub fn number_of_collections(&self) -> Option<i32>
pub fn number_of_collections(&self) -> Option<i32>
The number of collections within the collection group.
Sourcepub fn created_date(&self) -> Option<i64>
pub fn created_date(&self) -> Option<i64>
The Epoch time when the collection group was created.
Sourcepub fn capacity_limits(&self) -> Option<&CollectionGroupCapacityLimits>
pub fn capacity_limits(&self) -> Option<&CollectionGroupCapacityLimits>
Capacity limits for a collection group. These limits define the minimum and maximum OpenSearch Compute Units (OCUs) for indexing and search operations that can be used by collections in the group.
Sourcepub fn generation(&self) -> Option<&ServerlessGeneration>
pub fn generation(&self) -> Option<&ServerlessGeneration>
The generation of Amazon OpenSearch Serverless for the collection group.
Sourceimpl CollectionGroupSummary
impl CollectionGroupSummary
Sourcepub fn builder() -> CollectionGroupSummaryBuilder
pub fn builder() -> CollectionGroupSummaryBuilder
Creates a new builder-style object to manufacture CollectionGroupSummary.